==> haskell-postgresql-simple-0.6.5.1-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgresql-simple
version:              0.6.5.1
visibility:           public
id:                   postgresql-simple-0.6.5.1-5YpUtHv1wCQKHJ59ZSNmCV
key:                  postgresql-simple-0.6.5.1-5YpUtHv1wCQKHJ59ZSNmCV
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.
    (c) 2011-2018 Leon P Smith
    (c) 2018-2020 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Bryan O'\''Sullivan, Leon P Smith
synopsis:             Mid-Level PostgreSQL client library
description:
    Mid-Level PostgreSQL client library, forked from mysql-simple.

category:             Database
abi:                  3e441644d331f46c4dd9aced2c252ef0
exposed:              True
exposed-modules:
    Database.PostgreSQL.Simple Database.PostgreSQL.Simple.Arrays
    Database.PostgreSQL.Simple.Copy Database.PostgreSQL.Simple.Cursor
    Database.PostgreSQL.Simple.Errors
    Database.PostgreSQL.Simple.FromField
    Database.PostgreSQL.Simple.FromRow
    Database.PostgreSQL.Simple.HStore
    Database.PostgreSQL.Simple.HStore.Internal
    Database.PostgreSQL.Simple.Internal
    Database.PostgreSQL.Simple.LargeObjects
    Database.PostgreSQL.Simple.Newtypes
    Database.PostgreSQL.Simple.Notification
    Database.PostgreSQL.Simple.Ok Database.PostgreSQL.Simple.Range
    Database.PostgreSQL.Simple.SqlQQ Database.PostgreSQL.Simple.Time
    Database.PostgreSQL.Simple.Time.Internal
    Database.PostgreSQL.Simple.ToField Database.PostgreSQL.Simple.ToRow
    Database.PostgreSQL.Simple.Transaction
    Database.PostgreSQL.Simple.TypeInfo
    Database.PostgreSQL.Simple.TypeInfo.Macro
    Database.PostgreSQL.Simple.TypeInfo.Static
    Database.PostgreSQL.Simple.Types Database.PostgreSQL.Simple.Vector
    Database.PostgreSQL.Simple.Vector.Unboxed

hidden-modules:
    Database.PostgreSQL.Simple.Compat
    Database.PostgreSQL.Simple.HStore.Implementation
    Database.PostgreSQL.Simple.Internal.PQResultUtils
    Database.PostgreSQL.Simple.Time.Implementation
    Database.PostgreSQL.Simple.Time.Internal.Parser
    Database.PostgreSQL.Simple.Time.Internal.Printer
    Database.PostgreSQL.Simple.TypeInfo.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/postgresql-simple-0.6.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/postgresql-simple-0.6.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/postgresql-simple-0.6.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-simple
hs-libraries:         HSpostgresql-simple-0.6.5.1-5YpUtHv1wCQKHJ59ZSNmCV
depends:
    Only-0.1-2ALIOaFTuVl17VyQ33BnR1 aeson-2.1.2.1-Gng3eoGBP2Sj2fbUBsnWH
    attoparsec-0.14.4-E6IyHj0fKXuH5r9QvhZ8oW base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-IiC4W3ne2FhKO4v0Ko50kd
    containers-0.6.7 hashable-1.4.4.0-D3M5e9EeJxCJTqzfO7ugwa
    postgresql-libpq-0.9.5.0-ISIgXFjP19REFuF01eqmjw
    scientific-0.3.7.0-43723I2k3fJ8FjtljY7WIm template-haskell-2.19.0.0
    text-2.0.2 time-compat-1.9.6.1-DdDLMiRcssaDEtWaday75u
    transformers-0.5.6.2 uuid-types-1.0.6-DsLLzTzrUia2zyog8WMWmV
    vector-0.13.2.0-G0g5gCprguQ6M58H7uQE53

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-simple/html/postgresql-simple.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-simple-0.6.5.1-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgresql-simple
version:              0.6.5.1
visibility:           public
id:                   postgresql-simple-0.6.5.1-55S6anUVWnADZOblhqSfwq
key:                  postgresql-simple-0.6.5.1-55S6anUVWnADZOblhqSfwq
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.
    (c) 2011-2018 Leon P Smith
    (c) 2018-2020 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Bryan O'\''Sullivan, Leon P Smith
synopsis:             Mid-Level PostgreSQL client library
description:
    Mid-Level PostgreSQL client library, forked from mysql-simple.

category:             Database
abi:                  085bd7f09d029db239e9b552c0b5c63d
exposed:              True
exposed-modules:
    Database.PostgreSQL.Simple Database.PostgreSQL.Simple.Arrays
    Database.PostgreSQL.Simple.Copy Database.PostgreSQL.Simple.Cursor
    Database.PostgreSQL.Simple.Errors
    Database.PostgreSQL.Simple.FromField
    Database.PostgreSQL.Simple.FromRow
    Database.PostgreSQL.Simple.HStore
    Database.PostgreSQL.Simple.HStore.Internal
    Database.PostgreSQL.Simple.Internal
    Database.PostgreSQL.Simple.LargeObjects
    Database.PostgreSQL.Simple.Newtypes
    Database.PostgreSQL.Simple.Notification
    Database.PostgreSQL.Simple.Ok Database.PostgreSQL.Simple.Range
    Database.PostgreSQL.Simple.SqlQQ Database.PostgreSQL.Simple.Time
    Database.PostgreSQL.Simple.Time.Internal
    Database.PostgreSQL.Simple.ToField Database.PostgreSQL.Simple.ToRow
    Database.PostgreSQL.Simple.Transaction
    Database.PostgreSQL.Simple.TypeInfo
    Database.PostgreSQL.Simple.TypeInfo.Macro
    Database.PostgreSQL.Simple.TypeInfo.Static
    Database.PostgreSQL.Simple.Types Database.PostgreSQL.Simple.Vector
    Database.PostgreSQL.Simple.Vector.Unboxed

hidden-modules:
    Database.PostgreSQL.Simple.Compat
    Database.PostgreSQL.Simple.HStore.Implementation
    Database.PostgreSQL.Simple.Internal.PQResultUtils
    Database.PostgreSQL.Simple.Time.Implementation
    Database.PostgreSQL.Simple.Time.Internal.Parser
    Database.PostgreSQL.Simple.Time.Internal.Printer
    Database.PostgreSQL.Simple.TypeInfo.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/postgresql-simple-0.6.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/postgresql-simple-0.6.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/postgresql-simple-0.6.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-simple
hs-libraries:         HSpostgresql-simple-0.6.5.1-55S6anUVWnADZOblhqSfwq
depends:
    Only-0.1-2ALIOaFTuVl17VyQ33BnR1
    aeson-2.1.2.1-5BFfk7iI7w6HPWzhbIRzqn
    attoparsec-0.14.4-Lk9m0Bu4xLu6fNaGof6SYp base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-CCVT39CBetAFHWteAF796d
    containers-0.6.7 hashable-1.4.4.0-HayYj9uqgN4KUEsvzi6aVt
    postgresql-libpq-0.9.5.0-ISIgXFjP19REFuF01eqmjw
    scientific-0.3.7.0-KrMKCvnfUrQHIZNLkrXCwo template-haskell-2.19.0.0
    text-2.0.2 time-compat-1.9.6.1-GljZrNVcQbkAFzQhC1VhJ6
    transformers-0.5.6.2 uuid-types-1.0.6-DbsRnLkGwuo7vKOpcIvQ2R
    vector-0.13.2.0-KVjnIHG2Fg91rA02TsgQOf

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-simple/html/postgresql-simple.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
